@@ -4,7 +4,7 @@ import requests
 def config(API_Token):
     
     try:
-        auth_status = (requests.get("http://20.43.152.82:4000/authorize", headers={"x-access-token": API_Token})).json()
+        auth_status = (requests.get("http://20.43.152.82/authorize", headers={"x-access-token": API_Token})).json()
         dir_path, _ = os.path.split(__file__)
         if auth_status['status'] == "SUCCESS":
             with open(dir_path + "/config_variables.py", "w") as config_file:
